@@ -108,8 +108,8 @@ supports_xinput2_devices (void)
 
         gdk_error_trap_push ();
 
-        major = XI_2_Major;
-        minor = XI_2_Minor;
+        major = 2;
+        minor = 0;
 
         if (XIQueryVersion (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), &major, &minor) != Success) {
                 gdk_error_trap_pop_ignored ();
@@ -117,7 +117,7 @@ supports_xinput2_devices (void)
         }
         gdk_error_trap_pop_ignored ();
 
-        if ((major * 1000 + minor) < (XI_2_Major * 1000 + XI_2_Minor))
+        if ((major * 1000 + minor) < (2000))
                 return FALSE;
 
         return TRUE;
@@ -351,5 +351,7 @@ get_disabled_devices (GdkDeviceManager *manager)
                 ret = g_list_prepend (ret, GINT_TO_POINTER (device_info[i].id));
         }
 
+        XFreeDeviceList (device_info);
+
         return ret;
 }
